@@ -152,7 +152,7 @@ void qiv_display_text_window(qiv_image *q, const char *infotextdisplay,
   /* Display Push Any Key... message */
   pango_layout_set_text(layout, continue_msg, -1);
   pango_layout_get_pixel_size (layout, &temp, NULL);
-  gdk_draw_layout (q->win, q->text_gc, 
+  gdk_draw_layout (q->win, q->text_gc,
                    x + width/2 - temp/2,
                    y + height/2 - text_h/2 - descent + (i+1) * (ascent + descent),
                    layout);
@@ -179,7 +179,7 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
   // (because the user might have moved the window our since last redraw)
   if (!fullscreen) {
     gdk_window_get_position(q->win, &q->win_x, &q->win_y);
-//    g_print("position   : q->win_x = %d, q->win_y = %d, q->win_w = %d, mon = %d\n", q->win_x, q->win_y, q->win_w,q->mon_id);
+//    g_print("position   : q->win_x = %d, q->win_y = %d, q->win_w = %d, mon = %d, typ = %d\n", q->win_x, q->win_y, q->win_w,q->mon_id,ev->type);
   }
   q->mon_id = gdk_screen_get_monitor_at_window(screen, q->win);
 
@@ -190,13 +190,21 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
 
     case GDK_EXPOSE:
       if (!q->exposed) {
-        q->exposed = 1;
         qiv_set_cursor_timeout(q);
-      }
-      if(fullscreen) {
         if(center) center_image(q);
+      }
+      if(fullscreen)
+      {
         update_image(q, FULL_REDRAW);
       }
+      else
+      {
+        if(q->exposed)
+          update_image(q, MIN_REDRAW);
+        else
+          update_image(q, FULL_REDRAW);
+      }
+      q->exposed = 1;
       break;
 
     case GDK_LEAVE_NOTIFY:
@@ -223,26 +231,6 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
         // printf("GDK_CONFIGURE get_root_origin  %d %d\n",
         //        magnify_img.frame_x, magnify_img.frame_y);
       }
-      // gdk_draw_rectangle(q->win, q->status_gc, 1, 10, 10, 50, 50);
-      if (statusbar_window && !fullscreen) {
-#ifdef DEBUG
-        g_print("*** print statusbar at (%d, %d)\n", MAX(2,q->win_w-q->text_w-10), MAX(2,q->win_h-q->text_h-10));
-#endif
-        // printf(">>> statusbar_w %d %d %d %d\n",
-        //        MAX(2,q->win_w-text_w-10), MAX(2,q->win_h-text_h-10), text_w+5, text_h+5);
-
-        gdk_draw_rectangle(q->win, q->bg_gc, 0,
-                           MAX(2,q->win_w-q->text_w-10), MAX(2,q->win_h-q->text_h-10),
-                           q->text_w+5, q->text_h+5);
-        gdk_draw_rectangle(q->win, q->status_gc, 1,
-                           MAX(3,q->win_w-q->text_w-9), MAX(3,q->win_h-q->text_h-9),
-                           q->text_w+4, q->text_h+4);
-
-        pango_layout_set_text(layout, q->win_title, -1);
-        pango_layout_get_pixel_size (layout, &(q->text_w), &(q->text_h));
-        gdk_draw_layout (q->win, q->text_gc, MAX(5,q->win_w-q->text_w-7),  MAX(5,q->win_h-7-q->text_h), layout);
-      }
-
       break;
 
     case GDK_BUTTON_PRESS:
@@ -418,9 +406,9 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
           jcmd[jidx] = '\0';
           if (jumping) {
             jump2image(jcmd);
-          qiv_load_image(q);
-          jumping=0;
-        }
+            qiv_load_image(q);
+            jumping=0;
+          }
           else {      // extcommand=1
             int numlines = 0;
             const char **lines;
@@ -436,6 +424,23 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
         }
         /* else record keystroke if not null */
         else if(ev->key.string && *(ev->key.string) != '\0') {
+	  if (jumping) {
+            /* leave jumping mode on invalid input and process
+	     * input key as if it entered in non jumping mode */
+	    if((jidx == 0 &&
+	        (*(ev->key.string) != 'f' &&
+		 *(ev->key.string) != 'F' &&
+		 *(ev->key.string) != 'b' &&
+		 *(ev->key.string) != 'B' &&
+		 *(ev->key.string) != 't' &&
+		 *(ev->key.string) != 'T')) ||
+	       (jidx > 0 &&
+		(*(ev->key.string) < '0' || *(ev->key.string) > '9'))) {
+	      jumping = 0;
+	      qiv_handle_event(ev, data);
+	      return;
+	    }
+	  }
           jcmd[jidx++]=*(ev->key.string);
           jcmd[jidx] = '\0';
           if (extcommand)
@@ -581,12 +586,22 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
             update_image(q, MIN_REDRAW);
             break;
 
+            /* jpeg comments on/off  */
+
+          case 'J':
+            exit_slideshow = FALSE;
+            comment_window ^= 1;
+            snprintf(infotext, sizeof infotext, comment_window ?
+                     "(Comments: on)" : "(Comments: off)");
+            update_image(q, MIN_REDRAW);
+            break;
+
             /* Slide show on/off */
 
           case 's':
             exit_slideshow = FALSE;
             slide ^= 1;
-            if (slide) 
+            if (slide)
             {
               dpms_disable();
             }
@@ -852,19 +867,26 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
 
           case GDK_KEY_Delete:
           case 'd':
+          {
+            int ret;
             if (!readonly) {
-              if (move2trash() == 0)
+              if (trashbin == 1)
+                ret = move2trashbin();
+              else
+                ret = move2trash();
+
+              if (ret == 0)
                 snprintf(infotext, sizeof infotext, "(Deleted last image)");
               else
                 snprintf(infotext, sizeof infotext, "(Delete FAILED)");
               qiv_load_image(q);
             }
             break;
+          }
 
             /* Undelete image */
-
           case 'u':
-            if (!readonly) {
+            if (!readonly && !trashbin) {
               if (undelete_image() == 0)
                 snprintf(infotext, sizeof infotext, "(Undeleted)");
               else
@@ -872,7 +894,6 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
               qiv_load_image(q);
             }
             break;
-
             /* Copy image to selected directory */
 
           case 'a':
@@ -913,9 +934,10 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
             watch_file ^= 1;
             snprintf(infotext, sizeof infotext, watch_file ?
                      "(File watching: on)" : "(File watching: off)");
-            update_image(q, REDRAW);
+            update_image(q, MIN_REDRAW);
             if(watch_file){
-              g_idle_add (qiv_watch_file, q);
+              // check every 100ms
+              g_timeout_add_full(G_PRIORITY_DEFAULT_IDLE, 100, qiv_watch_file, q, NULL);
             }
             break;
 
@@ -949,7 +971,7 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
             to_root=1;
             set_desktop_image(q);
             snprintf(infotext, sizeof infotext, "(Centered image on background)");
-            update_image(q, REDRAW);
+            update_image(q, MIN_REDRAW);
             to_root=0;
             break;
 
@@ -959,7 +981,7 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
             to_root_t=1;
             set_desktop_image(q);
             snprintf(infotext, sizeof infotext, "(Tiled image on background)");
-            update_image(q, REDRAW);
+            update_image(q, MIN_REDRAW);
             to_root_t=0;
             break;
 
@@ -967,7 +989,7 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
             to_root_s=1;
             set_desktop_image(q);
             snprintf(infotext, sizeof infotext, "(Stretched image on background)");
-            update_image(q, REDRAW);
+            update_image(q, MIN_REDRAW);
             to_root_s=0;
             break;
 
@@ -1016,7 +1038,7 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
             }
             break;
           case ',':
-            if(fullscreen) 
+            if(fullscreen)
             {
               disable_grab ^= 1;
               snprintf(infotext, sizeof infotext, "(grab %s)", (disable_grab ? "off" : "on"));
@@ -1070,7 +1092,6 @@ void qiv_handle_event(GdkEvent *ev, gpointer data)
 #endif
           case 'F':
           case 'H':
-          case 'J':
           case 'K':
           case 'L':
           case 'M':
