@@ -23,9 +23,11 @@
 extern char *optarg;
 extern int optind, opterr, optopt;
 
-#define LONGOPT_VIKEYS 128
+/* put longopt-only options to non ascii values */
+#define LONGOPT_VIKEYS   256
+#define LONGOPT_TRASHBIN 257
 
-static char *short_options = "ab:c:Cd:efg:hilLmno:pq:rstuvw:xyzA:BDF:GIMNPRSTW:X:Y:Z:";
+static char *short_options = "ab:c:Cd:efg:hilLmno:pq:rstuvw:xyzA:BDF:GIJKMNPRSTW:X:Y:Z:";
 static struct option long_options[] =
 {
     {"do_grab",          0, NULL, 'a'},
@@ -62,6 +64,8 @@ static struct option long_options[] =
     {"file",             1, NULL, 'F'},
     {"disable_grab",     0, NULL, 'G'},
     {"statusbar",        0, NULL, 'I'},
+    {"showJPEGcomments", 0, NULL, 'J'},
+    {"mtime_sort",       0, NULL, 'K'},
     {"merged_case_sort", 0, NULL, 'M'},
     {"numeric_sort",     0, NULL, 'N'},
     {"ignore_path_sort", 0, NULL, 'P'},
@@ -74,11 +78,12 @@ static struct option long_options[] =
     {"source_profile",   1, NULL, 'Y'},
     {"display_profile",  1, NULL, 'Z'},
 #endif
+    {"trashbin",         0, NULL, LONGOPT_TRASHBIN},
     {"vikeys",           0, NULL, LONGOPT_VIKEYS},
     {0,                  0, NULL, 0}
 };
 
-static int numeric_sort = 0, merged_case_sort = 0, ignore_path_sort = 0;
+static int mtime_sort = 0, numeric_sort = 0, merged_case_sort = 0, ignore_path_sort = 0;
 
 /* This array makes it easy to sort filenames into merged-case order
  * (e.g. AaBbCcDdEeFf...). */
@@ -117,6 +122,17 @@ static unsigned char casemap[256] = {
     0xF8,0xF9,0xFA,0xFB,0xFC,0xFD,0xFE,0xFF
 };
 
+
+static time_t get_mtime(unsigned char *fn) {
+    struct stat attrib;
+
+    if(stat((char *) fn, &attrib) == 0)
+      return attrib.st_mtime;
+
+    return 0;
+}
+
+
 static int my_strcmp(const void *v1, const void *v2)
 {
     unsigned char *cp1 = *(unsigned char **)v1;
@@ -129,6 +145,15 @@ static int my_strcmp(const void *v1, const void *v2)
     sufptr2 = cp2 + strlen((char *)cp2);
     while (--sufptr2 > cp2 && *sufptr2 != '.') {}
 
+    if(mtime_sort) {
+        time_t diff = get_mtime(cp1) - get_mtime(cp2);
+        if(diff < 0)
+            return -1;
+        if(diff > 0)
+            return 1;
+        // fall through in case of same time stamp
+    }
+
     if (ignore_path_sort) {
         unsigned char *slash;
         if ((slash = (unsigned char *)strrchr((char *)cp1, '/')) != NULL)
@@ -244,7 +269,7 @@ void options_read(int argc, char **argv, qiv_image *q)
             case 'i': force_statusbar=0;
                 break;
 #if GDK_PIXBUF_MINOR >= 12
-            case 'l': autorotate=1;
+            case 'l': autorotate=0;           /* turn autorotation OFF, default is ON */
                 break;
 #endif
             case 'm': maxpect=1;
@@ -297,6 +322,10 @@ void options_read(int argc, char **argv, qiv_image *q)
                 break;
             case 'I': force_statusbar=1;
                 break;
+            case 'J': comment_window=1;
+                break;
+            case 'K': mtime_sort = 1;
+                break;
             case 'M': merged_case_sort = 1;
                 break;
             case 'N': numeric_sort = 1;
@@ -305,11 +334,11 @@ void options_read(int argc, char **argv, qiv_image *q)
                 break;
             case 'R': readonly=1;
                 break;
-            case 'S': shuffle=1;need_sort=0;
+            case 'S': shuffle=1; need_sort=0;
                 break;
             case 'T': watch_file=1;
                 break;
-            case 'W': fixed_zoom_factor = (checked_atoi(optarg) - 100) / 10;
+            case 'W': fixed_zoom_factor = (checked_atoi(optarg) - 100) / 10; zoom_factor = fixed_zoom_factor;
                 break;
             case 'X': user_screen = checked_atoi(optarg);
 //               g_print("set xinerama screen: %i\n", user_screen);
@@ -322,6 +351,9 @@ void options_read(int argc, char **argv, qiv_image *q)
 	        cms_transform = 1;
 	        break;
 #endif
+            case LONGOPT_TRASHBIN:
+                trashbin=1;
+                break;
             case LONGOPT_VIKEYS: vikeys=1;
               break;
             case 0:
@@ -330,8 +362,8 @@ void options_read(int argc, char **argv, qiv_image *q)
         }
     }
 
-    /* In case user specified -D and -P, -M, or -N */
-    need_sort = need_sort | ignore_path_sort | merged_case_sort | numeric_sort;
+    /* In case user specified -D and -K, -P, -M, or -N */
+    need_sort = need_sort | mtime_sort | ignore_path_sort | merged_case_sort | numeric_sort;
 
     /* default: show statusbar only in fullscreen mode */
     /* user wants to override? */
@@ -382,14 +414,16 @@ void options_read(int argc, char **argv, qiv_image *q)
             strcpy(tmp,image_names[0]);
         }
         rreaddir(dirname(image_names[0]),0);
-        filter_images(&images,image_names);
+        if(filter)
+            filter_images(&images,image_names);
         if(need_sort)
             qsort(image_names, images, sizeof *image_names, my_strcmp);
         image_idx = find_image(images,image_names,tmp);
         free(tmp);
     }
     else {
-        filter_images(&images,image_names);
+        if(filter)
+            filter_images(&images,image_names);
         if(need_sort)
             qsort(image_names, images, sizeof *image_names, my_strcmp);
     }
