@@ -118,6 +118,41 @@ int move2trash()
   return 0;
 }
 
+/* move current image to trash bin */
+int move2trashbin()
+{
+  GFile  *del_file;
+  GError *del_error=NULL;
+  int    i;
+  int    ret=0;
+
+  del_file=g_file_new_for_path(image_names[image_idx]);
+
+  if(g_file_trash(del_file, NULL, &del_error))
+  {
+    --images;
+    for(i=image_idx;i<images;++i) {
+      image_names[i] = image_names[i+1];
+    }
+
+    /* If deleting the last file out of x */
+    if(images == image_idx)
+      image_idx = 0;
+
+    /* If deleting the only file left */
+    if(!images)
+      exit(0);
+  }
+  else
+  {
+    printf("%s\n", del_error->message);
+    g_error_free(del_error);
+    ret=1;
+  }
+  g_object_unref(del_file);
+  return ret;
+}
+
 /* copy current image to SELECTDIR */
 int copy2select()
 {
@@ -341,8 +376,6 @@ void run_command(qiv_image *q, char *n, char *filename, int *numlines, const cha
     for (i = 0; i < *numlines; i++) {
       lines[i] = lines[i+1];
     }
-    update_image(q, FULL_REDRAW);
-    return;
   }
 
   stat(filename, &after);
@@ -492,6 +525,7 @@ void show_help(char *name, int exit_status)
           "    --readonly, -R         Disable the deletion feature\n"
           "    --maxpect, -m          Zoom to screen size and preserve aspect ratio\n"
           "    --merged_case_sort, -M Sort filenames with AaBbCc... alpha order\n"
+          "    --mtime_sort, -K       Sort files by their modification time\n"
           "    --no_filter, -n        Do not filter images by extension\n"
           "    --no_statusbar, -i     Disable statusbar\n"
           "    --statusbar, -I        Enable statusbar\n"
@@ -501,13 +535,15 @@ void show_help(char *name, int exit_status)
           "    --root_t, -y           Set tiled desktop background and exit\n"
           "    --root_s, -z           Set stretched desktop background and exit\n"
           "    --scale_down, -t       Shrink image(s) larger than the screen to fit\n"
+          "    --trashbin             Use users trash bin instead of .qiv_trash when deleting\n"
+          "                           (undelete key will not work in that case)\n"
           "    --transparency, -p     Enable transparency for transparent images\n"
           "    --watch, -T            Reload the image if it has changed on disk\n"
           "    --recursivedir, -u     Recursively include all files\n"
           "    --followlinks, -L      Follow symlinks to directories (requires --recursivedir)\n"
           "    --select_dir, -A x     Store the selected files in dir x (default is .qiv-select)\n"
 #if GDK_PIXBUF_MINOR >= 12
-          "    --autorotate, -l       Autorotate JPEGs according to EXIF rotation tag\n"
+          "    --autorotate, -l       Do NOT autorotate JPEGs according to EXIF rotation tag\n"
 #endif
           "    --rotate, -q x         Rotate 90(x=1),180(x=2),270(x=3) degrees clockwise (11 & 13 for conditional)\n"
           "    --xineramascreen, -X x Use monitor x as preferred screen\n"
@@ -515,6 +551,8 @@ void show_help(char *name, int exit_status)
           "    --source_profile, -Y x Use color profile file x as source profile for all images\n"
           "    --display_profile,-Z x Use color profile file x as display profile for all images\n"
 #endif
+          "    --vikeys               Enable movement with h/j/k/l, vi-style\n"
+          "                           (HJKL will do what hjkl previously did)\n"
           "    --version, -v          Print version information and exit\n"
           "\n"
           "Slideshow options:\n"
@@ -523,8 +561,7 @@ void show_help(char *name, int exit_status)
           "    --random, -r           Random order\n"
           "    --shuffle, -S          Shuffled order\n"
           "    --delay, -d x          Wait x seconds between images [default=%d]\n"
-          "    --vikeys               Enable movement with h/j/k/l, vi-style\n"
-          "                           (HJKL will do what hjkl previously did)\n"          "\n"
+          "\n"
           "Keys:\n", SLIDE_DELAY/1000);
 
     /* skip header and blank line */
@@ -722,7 +759,6 @@ gboolean qiv_watch_file (gpointer data)
               update_image(q, REDRAW);
           }
   }
-  usleep(200);  /* avoid eating 100% cpu */
 
   return TRUE;
 }
@@ -777,7 +813,7 @@ char *get_icc_profile(char *filename)
   if ((infile = fopen(filename, "rb")) == NULL)
   {
     fprintf(stderr, "can't open %s\n", filename);
-    return NULL; 
+    return NULL;
   }
 
   if (fread(pic_tst, 1, 4, infile) != 4)
@@ -792,7 +828,7 @@ char *get_icc_profile(char *filename)
     free(comment);
     comment=NULL;
   }
-  
+
   /* Is pic a jpg? */
   if ( (pic_tst[0] == 0xff) && (pic_tst[1] == 0xd8) && (pic_tst[2] == 0xff) &&  ((pic_tst[3]& 0xf0) == 0xe0) )
   {
@@ -801,14 +837,17 @@ char *get_icc_profile(char *filename)
     cinfo.err = jpeg_std_error(&jerr);
 
     jpeg_create_decompress(&cinfo);
-    jpeg_stdio_src(&cinfo, infile); 
+    jpeg_stdio_src(&cinfo, infile);
     jpeg_save_markers(&cinfo, 0xE2, 0xFFFF);
     jpeg_save_markers(&cinfo, JPEG_COM, 0xFFFF);
     jpg_ok = jpeg_read_header(&cinfo, 0);
+    if (jpg_ok == 0) {
+      qiv_exit(2);
+    }
     fclose(infile);
     jpeg_prog=cinfo.progressive_mode;
 
-    for (marker = cinfo.marker_list; marker != NULL; marker = marker->next) 
+    for (marker = cinfo.marker_list; marker != NULL; marker = marker->next)
     {
       if(strncmp(icc_string, (const char *)marker->data, 11)==0)
       {
@@ -833,6 +872,15 @@ char *get_icc_profile(char *filename)
         comment=calloc(1+marker->data_length,1);
         if(comment==NULL) return NULL;
         strncpy(comment, (char *) marker->data, marker->data_length);
+
+        /* simulate perl's chomp */
+        int len = strlen(comment);
+        while (isspace(comment[len-1]))
+        {
+          comment[len-1] = 0;
+          if(--len==0)
+            break;
+        }
       }
     }
     if(i==0)
@@ -863,7 +911,7 @@ char *get_icc_profile(char *filename)
     return icc_ptr;
   }
   /* is pic a tiff?*/
-  else if((pic_tst[0] == pic_tst[1]) && ((pic_tst[0] == 0x49)||(pic_tst[0] == 0x4d)) && (pic_tst[2] == 0x2a) &&  (pic_tst[3] == 0x00)) 
+  else if((pic_tst[0] == pic_tst[1]) && ((pic_tst[0] == 0x49)||(pic_tst[0] == 0x4d)) && (pic_tst[2] == 0x2a) &&  (pic_tst[3] == 0x00))
   {
     uint16 count;
     unsigned char *data;
@@ -1002,7 +1050,7 @@ char **get_exif_values(char *filename)
     snprintf(line, 255, "%-21s: %s\n", "Comment", comment);
     exif_lines[j++]=line;
   }
-    
+
   return exif_lines;
 }
 #endif
@@ -1019,7 +1067,7 @@ void dpms_check()
   CARD16 power_level;
 
   if(DPMSQueryExtension(disp, &not_needed, &not_needed))
-  { 
+  {
     if(DPMSCapable(disp))
     {
       DPMSInfo(disp, &power_level, &dpms_enabled);
